#
# spec file for package fplll
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fplll
%define lname   libfplll9
Version:        5.5.0
Release:        1.2
Summary:        Lenstra-Lovász Lattice Basis Reduction Algorithm Library
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/dstehle/fplll

#Git-Clone:	https://github.com/fplll/fplll
Source:         https://github.com/fplll/fplll/releases/download/%version/fplll-%version.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  memory-constraints
BuildRequires:  mpfr-devel
BuildRequires:  pkg-config

%description
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

%package -n %lname
Summary:        Lenstra-Lovász Lattice Basis Reduction Algorithm Library
Group:          System/Libraries

%description -n %lname
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

%package devel
Summary:        Development files for Lattice Basis Reduction with libfplll
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      libfplll-devel < %version-%release
Provides:       libfplll-devel = %version-%release

%description devel
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

This subpackage contains libraries and header files for developing
applications that want to make use of libfplll.

%prep
%autosetup

%build
%limit_build -m 1700
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files
%doc NEWS README.md
%license COPYING
%_bindir/fplll
%_bindir/latticegen
%_datadir/fplll/

%files -n %lname
%_libdir/libfplll.so.*

%files devel
%_includedir/fplll*
%_libdir/libfplll.so
%_libdir/pkgconfig/*.pc

%changelog
* Tue Nov 12 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.5.0
  * No changelog was provided
* Wed Oct 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.5
  * Replace deprecated std::result_of by std::invoke_result
* Thu Jan  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.4
  * Make Babai test more robust for PPC
* Tue Dec 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.3
  * Add FP_NR::ceil function
* Fri Dec  9 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Limit build parallelism with limit_build macro to avoid
  occasional build failure due to OOM.
* Wed May 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.2
  * Exacteval fix
  * Document the role of the `u` parameter in LLL_reduction
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.1
  * Add -I flags to pkgconfig file
  * GCC11 support
* Fri Dec  4 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.0
  * No changelog was provided
* Mon Jun 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.3
  * No changelog was provided
* Thu Jan  9 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.2
  * Nobody has any intention of providing a changelog.
* Sat Dec 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.1
  * No changelog was provided
* Sun Nov 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.0
  * No changelog was provided
* Sat Oct 20 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 5.2.1
  * Unify randomness on 32-bit and 64-bit systems
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 5.2.0
  * Bkz dump_gso in json
  * Improve pruner
  * BKZ with Z_NR<long>
  * Z_NR<long> support
  * Allow BOUNDED_LLL in Slide reduction and remove LLL from
    postprocessing by Michael Walter
  * Add Gram-matrix object
* Sat Sep  9 2017 jengelh@inai.de
- Update to new upstream release 5.1.0
  * CVP is not experimental any longer by implementing the
    resetting feature.
  * Pruner rewrite providing faster pruning, a new greedy pruning
    strategy, support for multiple solutions and a simpler API.
  * Support for external enumeration libraries paving the way for
    multithreaded/MPI/GPU enumeration libraries.
  * Gaussian Heuristic improved and renamed to
    `adjust_radius_to_gh_bound`.
  * Reduced calls to LLL during BKZ.
  * Evaluator rewrite/refactoring now supporting different
    evaluation strategies.
- Rename SRPM from libfplll to fplll.
  No binary packages are affected.
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 5.0.3
  * No changelog was provided
* Mon Feb  2 2015 jengelh@inai.de
- Add git repository metadata
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 4.0.4
  * compatibility for packages that still expect to build against
  libfplll version 3.
  * Compilation fixes: updates of config.sub and config.guess, and
  a better check that MPFR and GMP are installed.
* Fri May 17 2013 jengelh@inai.de
- Update to new upstream release 4.0.3
  * Fixed compiler issues for Cygwin and warnings
* Thu Nov 29 2012 jengelh@inai.de
- Update to new upstream release 4.0.1
  * Resolved compiler warnings about unused parameters
* Sat Aug 25 2012 dmitry@roshchin.org
- Update to version 4.0.0
  * BKZ reduction, available with `fplll -a bkz -b blocksize`
* Sun Feb 26 2012 scorot@free.fr
- fix build for SLE-11
- add missing %%post and %%postun scriplets
* Sun Nov 20 2011 werner.ho@gmx.de
- new version 3.1.3
* Tue Sep 27 2011 jengelh@medozas.de
- Initial package (version 3.1.2) for build.opensuse.org
